@@ -4,6 +4,7 @@ import logging
 import os
 import subprocess
 import sys
+from collections import defaultdict
 from datetime import datetime
 from typing import TYPE_CHECKING
 
@@ -160,8 +161,17 @@ def shell(
     if not shell:
         raise TypeError("'shell' is None")
 
+    shell_cmd_param = defaultdict(
+        lambda: "-c",
+        {
+            "cmd": "/c",
+            "powershell": "-Command",
+            "pwsh": "-Command",
+        },
+    )
+
     return subprocess.run(  # noqa: S603
-        [shell, "-c" if shell != "cmd" else "/c", cmd],
+        [shell, shell_cmd_param[shell], cmd],
         env=(env or {}),
         check=check,
     )
@@ -701,7 +711,8 @@ def version(  # noqa: C901
     release_notes = generate_release_notes(
         hvcs_client,
         release_history.released[new_version],
-        template_dir=runtime.template_dir,
+        runtime.template_dir,
+        history=release_history,
     )
 
     exception: Exception | None = None
